@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT @EXPORT_OK);
-$VERSION = '5.05';
+$VERSION = '5.06';
 
 =head1 NAME
 
@@ -12,7 +12,8 @@ Labyrinth::Users - Generic User functions for Labyrinth
 
 =head1 DESCRIPTION
 
-Contains generic user functionality
+Contains generic user functionality that are required across the Labyrinth
+framework, and may be used within plugins.
 
 =cut
 
@@ -54,12 +55,20 @@ my (%usernames,%userids);  # quick lookup hashes
 
 =item UserName($id)
 
+Given a user id, returns the user's name.
+
 =item UserID
 
+Given a user's name (real name or nick name), returns the user id.
+
 =item FreshPassword
 
+Returns a generated password string.
+
 =item PasswordCheck
 
+Checks the given password against the required rules.
+
 =back
 
 =cut
@@ -133,6 +142,11 @@ sub PasswordCheck {
 
 =item UserSelect
 
+Provides a dropdown selection box, as a XHTML code snippet, of the currently 
+listed users.
+
+By default only users listed as searchable are listed.
+
 =back
 
 =cut
